# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-IPC-Run
Version:	20231003.0
Release:	1.%{__distinit}%{__distvers}
Summary:	Perl module for interacting with child processes
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/IPC-Run
Source0:	https://cpan.metacpan.org/modules/by-module/IPC/IPC-Run-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(bytes)
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IO::Pty) >= 1.08
BuildRequires:	perl(POSIX)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Socket)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Text::ParseWords)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(B)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Encode)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Tty)
BuildRequires:	perl(Test::More) >= 0.47
# Optional Tests
BuildRequires:	perl(Readonly)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Data::Dumper)
Requires:	perl(File::Basename)
Requires:	perl(IO::Pty) >= 1.08

%description
IPC::Run allows you run and interact with child processes using files,
pipes, and pseudo-ttys. Both system()-style and scripted usages are
supported and may be mixed. Likewise, functional and OO API styles are
both supported and may be mixed.

Various redirection operators reminiscent of those seen on common Unix
and DOS command lines are provided.

%prep
%setup -q -n IPC-Run-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

# Remove Windows-only features that could add unnecessary dependencies
rm -f %{buildroot}%{perl_vendorlib}/IPC/Run/Win32*.pm
rm -f %{buildroot}%{_mandir}/man3/IPC::Run::Win32*.3*

%check
make test

%files
%license LICENSE
%doc Changelog eg/ README.md
%{perl_vendorlib}/IPC/
%{_mandir}/man3/IPC::Run.3*
%{_mandir}/man3/IPC::Run::Debug.3*
%{_mandir}/man3/IPC::Run::IO.3*
%{_mandir}/man3/IPC::Run::Timer.3*

%changelog
* Tue Oct  3 2023 Paul Howarth <paul@city-fan.org> - 20231003.0-1
- Update to 20231003.0
  - On Windows, avoid hang under IPCRUNDEBUG (GH#157)
  - Refresh "cpanfile" from Makefile.PL, to allow use on Windows
  - Normalize shebangs to /usr/bin/perl (GH#163)
  - Fix or skip all tests recently seen to fail on Windows
  - Include t/result.t in releases
  - Make full_result() and result() Windows behaviour match non-Windows (GH#168)

* Tue Apr 18 2023 Paul Howarth <paul@city-fan.org> - 20220807.0-3
- Use SPDX-format license tag

* Sun Aug  7 2022 Paul Howarth <paul@city-fan.org> - 20220807.0-1
- Update to 20220807.0
  - If your applications rely on portability to Windows, see new documentation
    sections "argument-passing rules are program-specific" and "batch files"
    - This release fixes bugs in runs of Windows programs that use standard
      command line parsing rules
    - Runs of non-standard programs may require changes; notable non-standard
      programs include cmd.exe, cscript.exe, and Cygwin programs
  - Skip t/pty.t test on NetBSD too (GH#140)
  - Add strict/warnings
  - Follow Windows argument quoting rules (GH#142)
  - Allow win32_newlines.t to actually run (GH#146)
  - Make t/pty.t test pass on OpenBSD (GH#150)
  - Support Win32 commands having non-standard command line parsing rules
    (GH#148)
  - Support executing Win32 batch files
  - Add IPC::Run::Win32Process, for delivering non-standard command lines
  - Fix reporting of Win32::Process::Create() errors
  - On Windows, avoid hang when closing read end of pipe (GH#156)
  - Ignore known test failure on msys - t/windows_search_path.t (GH#155)
  - Avoid warning with IPCRUNDEBUG, in Windows spawned children
  - Use $^X, not 'perl', in tests
  - Thanks to the new active developer: Noah Misch!
- Use %%license unconditionally

* Wed May  6 2020 Paul Howarth <paul@city-fan.org> - 20200505.0-1
- Update to 20200505.0
  - Fix syntax errors in POD examples (GH#125)
  - Switch Readonly testing requirement to a recommends (GH#127)
  - Fix full_result to always return $? (GH#129)
  - kill_kill: Immediately KILL the child process as documented for Win32 (GH#136)
  - Switch to GitHub actions for CI testing
  - Re-structure shipped files into eg/
  - Move author tests into xt/ and test them separately

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 20180523.0-5
- Perl 5.30 rebuild

* Thu May 24 2018 Paul Howarth <paul@city-fan.org> - 20180523.0-1
- Update to 20180523.0
  - Fix using fd in child process when it happens to be the same number in the
    child as it was in the parent (GH#99)
- Switch upstream from search.cpan.org to metacpan.org

* Sat Mar 31 2018 Paul Howarth <paul@city-fan.org> - 0.99-1
- Update to 0.99
  - Fixes for Windows unit tests so they skip or pass
    - t/autoflush.t
    - t/readonly.t
    - t/run_stdin-callback-return-array.t

* Fri Mar 30 2018 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98
  - Switch to using $!{EINTR}
  - Honor umask for user/group permissions on a +rw file
  - Remove commented code from CPAN RT#50739
  - Fix _write on invalid objects (GH#63)
  - Make slave the controlling terminal so more programs can be called from
    IPC::Run reliably (GH#54)
  - Prevent Not a GLOB reference in close_terminal by untieing before close
    (GH#53)
  - Fix '&' closing the stdin of the right process (GH#46)
  - Do POSIX::_exit not ::exit (GH#41)
  - Ensure child Win32 processes have same priority as parent (GH#40)
  - Add unit test for passing use of Readonly.pm (GH#38)
  - Fix GLOB test in IPC::Run::IO->new (GH#39)
  - Fix for memory leak (GH#86, CPAN RT#57990)
  - MANIFEST was updated; new tests may start shipping now

* Tue Mar 27 2018 Paul Howarth <paul@city-fan.org> - 0.97-1
- Update to 0.97
  - Update meta and POD to point to GitHub issues not RT
  - Update README with pod changes
  - Fix variable name in synopsis (GH#47)
  - Fix t/run.t to work on "perl in space" (GH#100)
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Sat May 13 2017 Paul Howarth <paul@city-fan.org> - 0.96-1
- Update to 0.96
  - Update bug tracker to https://github.com/toddr/IPC-Run/issues

* Tue Apr 25 2017 Paul Howarth <paul@city-fan.org> - 0.95-1
- Update to 0.95
  - Enable Travis-CI integration for IPC::Run
  - Use q{} and qq{} to fix problems with quotation in cmd.exe
  - Sync $VERSION across all files to address kwalitee
  - Stop side effect of altering flushing of STDOUT and STDERR (CPAN RT#109243)
  - CHILD_HANDLE should be closed with 'Close' to prevent a warning
  - Require Win32API::File on Windows
  - Better timer error message plus an additional unit test
  - Catching previously non-detected malformed time strings
  - Let Timer accept all allowable perl numbers
  - Allow the OS to choose the ephemeral port to use
  - Don't use version.pm to parse the perl version in Makefile.PL
  - perltidy
  - Do not import POSIX into local namespace (it's a memory hog)
  - Skip infinity test on perl below 5.8.9
  - Spelling fixes
  - Documentation fix: full_result returns $?, not $? >> 8
  - Fix check for reaped PID in reap_nb
  - Re-remove unnecessary use of UNIVERSAL
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Wed Aug 31 2016 Paul Howarth <paul@city-fan.org> - 0.94-5
- BR: perl-generators where available
- Simplify find command using -delete

* Mon Dec 15 2014 Paul Howarth <paul@city-fan.org> - 0.94-1
- Update to 0.94
  - Update License discrepancies (CPAN RT#100858)
  - Many typo corrections
  - Fix t/pty.t fails on Solaris 10 (CPAN RT#20105)
- Drop upstreamed patch for CPAN RT#20105

* Thu Dec 11 2014 Paul Howarth <paul@city-fan.org> - 0.93-1
- Update to 0.93
  - Add aggressive exit to t/signal.t after skip_all to prevent failures
    (CPAN RT#100711)
  - Fix for run argument with spaces in path (CPAN RT#97926)
  - Skip t/win32_compile.t on Android
  - TODO failing POD tests for IPC::Run (CPAN RT#86133)
- Classify buildreqs by usage

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 0.92-7
- Use %%license where possible

* Tue May  6 2014 Paul Howarth <paul@city-fan.org> - 0.92-5
- Address intermittent test failures (CPAN RT#20105, RH BZ#1094395)
- No longer need to fix file permissions
- Drop %%defattr, redundant since rpm 4.4

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 0.92-3
- Work around incomplete POD coverage of Win32 code (CPAN RT#86133)

* Thu Aug 30 2012 Paul Howarth <paul@city-fan.org> - 0.92-1
- Update to 0.92:
  - Catching a signal during select() can lock up IPC::Run (CPAN RT#59775)

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.91-4
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  1 2012 Paul Howarth <paul@city-fan.org> - 0.91-3
- BR:/R: perl(Data::Dumper)
- Drop buildreqs for Perl core modules that are not actually dual-lived

* Tue Mar 13 2012 Paul Howarth <paul@city-fan.org> - 0.91-2
- Don't BR: perl(Test::MinimumVersion) when bootstrapping
- Add buildreqs for Perl core modules that might be dual-lived
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Feb 15 2012 Paul Howarth <paul@city-fan.org> - 0.91-1
- Update to 0.91:
  - CPAN RT#57277: timeout causes delay with output not captured

timeout causes delay with output not captured
* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.90-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Jul  4 2011 Paul Howarth <paul@city-fan.org> - 0.90-1
- Update to 0.90:
  - CPAN RT#14078: run() miscalculates length of UTF-8 strings
  - CPAN RT#38193: fix error detection on non-English operating systems
  - CPAN RT#43072: skip dragonfly platform on t/pty.t (hangs)
  - CPAN RT#49693: security patch for lib/IPC/Run/Win32IO.pm s/INADDR_ANY//
  - CPAN RT#57190: handle PATH environment variable not being defined
  - CPAN RT#57277: add breaking test; no solution at present
  - CPAN RT#68623: disable parallel tests on Windows
  - Add a blank doc entry for IPC::Run::Win32IO::poll to quiet Windows pod
    parser errors
- Drop upstreamed patch for CPAN RT#38193
- Nobody else likes macros for commands

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 0.89-3
- Rebuild for perl 5.12.1 in Rawhide

* Fri Jun  4 2010 Paul Howarth <paul@city-fan.org> - 0.89-2
- Fix dist tag for RHEL-6 Beta

* Thu Apr  1 2010 Paul Howarth <paul@city-fan.org> - 0.89-1
- Update to 0.89
  - Revert extended tests to require "oslo consensus" variables
  - Add IO::Pty to META.yml requirement

* Wed Mar 31 2010 Paul Howarth <paul@city-fan.org> - 0.88-1
- Update to 0.88
  - Missed dangling isa in IPC::Run::Debug
  - Fix retry for read of fh when getting "Resource temporarily unavailable"
  - Fix POD indentation in IO.pm
- Update patch for CPAN RT#38193

* Tue Mar 30 2010 Paul Howarth <paul@city-fan.org> - 0.87-1
- Update to 0.87
  - Add doc type fixes (CPAN RT#56030)
  - Remove recommends for AUTHOR only modules
  - Add pod_coverage and simplify pod test
  - Document undocumented public subs with TODO
  - Explicitly recommend IO::Pty version number 1.08
- BuildRequire perl(Test::Pod::Coverage) >= 1.04
- Bump IO::Pty/IO::Tty requirement to 1.08
- Update patch for CPAN RT#38193 to not create .orig file

* Thu Mar 25 2010 Paul Howarth <paul@city-fan.org> - 0.86-1
- Update to 0.86
  - Remove use UNIVERSAL (CPAN RT#51509)
  - Fix POD for Win32Helper (CPAN RT#51695)
  - Better PATHEXT logic in case cmd_name contains periods (CPAN RT#50739)
  - Enhance tests for run.t for better diagnostics (CPAN RT#47630)
  - Add all files to subversion for easier releases
  - Bump version on ALL files to 86
- This release by TODDR -> update source URL
- Update patch for CPAN RT#38193 to not create .orig file

* Fri Feb 19 2010 Paul Howarth <paul@city-fan.org> - 0.84-3
- Add patch for CPAN RT#38193 (oversensitivity to locale)
- Re-enable t/pty.t
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Sep  4 2009 Paul Howarth <paul@city-fan.org> - 0.84-2
- IPCRUNDEBUG not needed in %%check; issue fixed long ago

* Mon Jul 13 2009 Paul Howarth <paul@city-fan.org> - 0.84-1
- Update to 0.84 (add darwin to the list of known-bad platforms)

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> - 0.83-1
- Update to 0.83 (fix for Windows 2008)
- Add buildreqs perl(Test::CPAN::Meta), perl(Test::Pod), and
  perl(Test::MinimumVersion), then enable author tests
- Define RPM macros in global scope
- Don't run t/pty.t as it's prone to intermittent fails (CPAN RT#20105)

* Tue Jan 20 2009 Paul Howarth <paul@city-fan.org> - 0.82-2
- Use versioned buildreqs for IO::Tty and Test::More
- Include LICENSE, README, and abuse/ in docs

* Fri Dec 19 2008 Paul Howarth <paul@city-fan.org> - 0.82-1
- Update to 0.82 (code refactoring)
- New upstream maintainer -> new source URL
- Buildreq Test::More

* Fri Nov 14 2008 Paul Howarth <paul@city-fan.org> - 0.80-5
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Fri Jun 29 2007 Paul Howarth <paul@city-fan.org> - 0.80-4
- Import from Fedora

* Tue Apr 17 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.80-3
- BuildRequire perl(ExtUtils::MakeMaker).

* Wed Aug 30 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.80-2
- Fix order of arguments to find(1).

* Thu May 11 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.80-1
- 0.80, fine tune build dependencies.

* Tue Jan 17 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.79-3
- Rebuild, cosmetic cleanups.

* Sun Apr 10 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.79-2
- Exclude Win32 specific modules.
- Include more docs.
- Skip tests if /dev/pts doesn't exist.

* Sat Apr  2 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.79-1
- 0.79.

* Sat Apr  2 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.78-2
- Sync with fedora-rpmdevtools' Perl spec template.
- Improve dependency filtering script.

* Sun Mar 14 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.78-0.fdr.1
- Update to 0.78.

* Sun Feb  1 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.77-0.fdr.4
- Reduce directory ownership bloat.

* Fri Nov 21 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.77-0.fdr.3
- BuildRequire perl-IO-Tty for better test coverage.

* Sat Oct 11 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.77-0.fdr.2
- Fix typo in dependency filtering scriptlet.

* Sat Sep 27 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.77-0.fdr.1
- Update to 0.77.

* Fri Sep  5 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.75-0.fdr.3
- Avoid Win32-specific dependencies.
- Use PERL_INSTALL_ROOT.

* Sun Aug 31 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.75-0.fdr.2
- Install into vendor dirs.

* Thu Jun 19 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:0.75-0.fdr.1
- First build.
